@@ -6,8 +6,6 @@
 ( cd opt/kde/share/doc/HTML/en/kmoon ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kweather ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kaphorism ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kworldclock ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kteatime ; rm -rf common )
